pilot.impl.pilotdata_manager

Package pilot :: Package impl :: Module pilotdata_manager |

# Module pilotdata_manager

source code

PilotData Module: Implementation of PilotData, PilotDataService and DataUnit

Classes
| PilotData PilotData (PD).
| PilotDataService PilotDataService (PDS).
| DataUnit DataUnit (DU).
| DataUnitItem DataUnitItem

Functions
test_pd_reconnect() | source code
test_du_reconnect() | source code
test_data_unit_add_file() | source code

Variables
| application_id = ``'``bigdata``'`` Implementation considerations:
| COORDINATION_URL = ``'``redis://localhost``'``
| __package__ = ``'``pilot.impl``'``

Variables Details

  ### application_id Implementation considerations: PilotDataService can have n PilotData PilotData can have n DataUnits (only DU URLs is held to avoid circular dependencies) A DataUnit can be part of n PilotData Value:
      'bigdata'